==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/zh-CN.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "管理灯箱GALLARY参数");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "管理图库");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "全尺寸图片宽度");
define('MANAGE_GALLERY_FULL_HEIGHT', "全尺寸图片高度");
define('MANAGE_GALLERY_THUMB_WIDTH', "缩略图宽度");
define('MANAGE_GALLERY_THUMB_HEIGHT', "缩略图高度");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "保留拇指长宽比");
define('MANAGE_GALLERY_SHOW_TITLES', "显示标题");
define('MANAGE_GALLERY_DISABLE_SORT', "禁用排序");
define('MANAGE_GALLERY_DELETE_IMAGE', "删除图像");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "保存排序顺序");
define('MANAGE_GALLERY_PUBLISH_MSG', "点击“更新”发布<br />您上传的图片。");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "所有图像都被调整和设置已保存。");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "有一个错误的调整图像或保存设置。");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "您的图像（S）已上载。");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "有一个错误上传您的图像（S）。");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "您要上传的文件不是图像。");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "您要上传的文件过大。");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "标题已保存。");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "你确定要删除的图像");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "？");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "图像已被删除。");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "有一个错误删除图像。");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "保存参数和调整图像大小，请稍候...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "上传文件，请稍候...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "排序顺序尚未保存。你要保存的排序顺序？");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "图像排序顺序已保存。");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "有一个错误保存图像排序。");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/zh-CN.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "管理灯箱GALLARY参数");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "管理图库");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "全尺寸图片宽度");
define('MANAGE_GALLERY_FULL_HEIGHT', "全尺寸图片高度");
define('MANAGE_GALLERY_THUMB_WIDTH', "缩略图宽度");
define('MANAGE_GALLERY_THUMB_HEIGHT', "缩略图高度");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "保留拇指长宽比");
define('MANAGE_GALLERY_SHOW_TITLES', "显示标题");
define('MANAGE_GALLERY_DISABLE_SORT', "禁用排序");
define('MANAGE_GALLERY_DELETE_IMAGE', "删除图像");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "保存排序顺序");
define('MANAGE_GALLERY_PUBLISH_MSG', "点击“更新”发布<br />您上传的图片。");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "所有图像都被调整和设置已保存。");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "有一个错误的调整图像或保存设置。");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "您的图像（S）已上载。");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "有一个错误上传您的图像（S）。");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "您要上传的文件不是图像。");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "您要上传的文件过大。");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "标题已保存。");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "你确定要删除的图像");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "？");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "图像已被删除。");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "有一个错误删除图像。");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "保存参数和调整图像大小，请稍候...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "上传文件，请稍候...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "排序顺序尚未保存。你要保存的排序顺序？");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "图像排序顺序已保存。");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "有一个错误保存图像排序。");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "您尝试上传的文件大于&#39;upload_max_filesize&#39;或&#39;post_max_size&#39;PHP设置。请与系统管理员联系以增加这些限制。");
?>
